@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright 2007      Johannes Bergmeier <johannes.bergmeier@gmx.net>   *
+ *   Copyright 2015      Ian Wadham <iandw.au@gmail.com>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +25,7 @@
 
 #include "ksudokugame.h"
 #include "globals.h"
+#include "puzzle.h"
 
 Q_DECLARE_METATYPE(ksudoku::GameVariant*)
 
@@ -127,6 +129,7 @@ void WelcomeScreen::startEmptyGame() {
 	if(!variant) return;
 	
 	Game game = variant->startEmpty();
+	if (! game.isValid()) return;
 	
 	emit newGameStarted(game, variant);
 }
@@ -157,7 +160,11 @@ void WelcomeScreen::generatePuzzle() {
 	gameGroup.writeEntry("Symmetry"  , m_symmetry);
 	gameGroup.sync();		// Ensure that the entry goes to disk.
 
-	emit newGameStarted(game, variant);
+	// If the user abandoned puzzle-generation, stay on the Welcome Screen
+	// and allow the user to change the Difficulty, etc. of the puzzle.
+	if (game.puzzle()->hasSolution()) {
+	    emit newGameStarted(game, variant);		// OK, start playing.
+	}
 }
 
 }
